@@ -109,7 +109,7 @@ retry:
         	return 0;
 	}
 	*open_port = p;
-	ret = d_alloc(sizeof(S_ACCEPT),184);
+	ret = d_alloc(sizeof(S_ACCEPT));
 	ret->h.tbl = &s_accept_table;
 	ret->h.thread = 0;
 	ret->accept.fid = sd;
