@@ -38,6 +38,8 @@ int s_vprintf_cr_socket();
 int s_flush_socket();
 int s_vscanf_socket();
 
+int s_get_socketip_socket(STREAM * s);
+
 S_TABLE s_socket_table = {
 	's',
 	0,
@@ -49,7 +51,8 @@ S_TABLE s_socket_table = {
 	s_read_socket,
 	s_flush_socket,
 	0,
-	0
+	0,
+	s_get_socketip_socket
 };
 
 int
@@ -95,55 +98,15 @@ s_read_socket(STREAM * s, void * data, int len)
 	return recv(s->_socket.fid, data, len, 0);
 }
 
-
-/*
-int
-s_vprintf_socket(STREAM * s, char * string)
-{
-	send(s->_socket.fid, string, strlen(string), 0);
-	return strlen(string);
-}
-
-int
-s_vprintf_cr_socket(STREAM * s, char * string)
-{
-char * ptr;
-	lock_task(stream_lock);
-	for ( ptr = string ; *ptr ; ptr ++ )
-		if ( *ptr == '\n' || *ptr == '\r' )
-			s->h.cr_cnt ++;
-	unlock_task(stream_lock, "s_vprintf_cr_file");
-	send(s->_socket.fid, string,strlen(string), 0);
-	return strlen(string);
-}
-*/
-
 int
 s_flush_socket(STREAM * s)
 {
+
 	return 0;
 }
-/*
-S_FILE __s_std[3] = {
-	{	{	&s_file_table,
-			O_RDONLY
-		},
-		stdin
-	},
-	{	{	&s_file_table,
-			O_WRONLY
-		},
-		stdout
-	},
-	{	{	&s_file_table,
-			O_WRONLY
-		},
-		stderr
-	}
-};
-*/
+
 int
-s_get_socketip(STREAM * s)
+s_get_socketip_socket(STREAM * s)
 {
 int ret;
 int er;
