@@ -28,7 +28,7 @@ URL u;
 L_CHAR * f;
 int ret;
 U_STAT buf;
-	get_url2(&u,filename,36);
+	get_url2(&u,filename);
 	f = get_access_path(&u,prefix);
 	if ( f == 0 )
 		return 0;
