@@ -1916,15 +1916,7 @@ TRIANGLE * t1, * t2;
 	c = c->next;
 	coordinate_unit_to_host(&ret->map.cu_src,&c);
 	coordinate_unit_to_host(&ret->map.cu_dest,&c);
-/*
-	url = ll_copy_str(get_url_str2(&ret->map.src));
-	setup_c_unit(&ret->map.cu_src,w->ses,url,0,0);
-	d_f_ree(url);
 
-	url = ll_copy_str(get_url_str2(&ret->map.dest));
-	setup_c_unit(&ret->map.cu_dest,w->ses,url,0,0);
-	d_f_ree(url);
-*/
 	w->flags |= RSBF_MAP;
 	INIT_RING(&ret->map.point_list);
 
