@@ -177,7 +177,7 @@ MAP * m;
 	for ( m = R_NEXT(MAP*,&r->c.map_children) ;
 			m != (MAP*)&r->c.map_children;
 			m = R_NEXT(MAP*,&m->h) )
-		if ( url_cmp(&m->src_url,u) == 0 )
+		if ( url_cmp_str(&m->src_url,u) == 0 )
 			return m;
 	return 0;
 }
@@ -460,7 +460,7 @@ ss_printf("* TIME = %i\n",index_time);
 			goto next;
 		}
 		get_url2(&url_buf,dest);
-		if ( url_cmp(&url_buf,&r->h.entry) != 0 ) {
+		if ( url_cmp_str(&url_buf,&r->h.entry) != 0 ) {
 			free_url(&url_buf);
 			goto next;
 		}
@@ -469,7 +469,7 @@ ss_printf("* TIME = %i\n",index_time);
 		for ( m = R_NEXT(MAP*,&r->c.map_children) ;
 				m != (MAP*)&r->c.map_children;
 				m = R_NEXT(MAP*,&m->h) )
-			if ( url_cmp(&m->src_url,&url_buf) == 0 )
+			if ( url_cmp_str(&m->src_url,&url_buf) == 0 )
 				goto next;
 		mod = get_el_by_symbol(sr,l_string(std_cm,"mod"),0);
 		m1 = d_alloc(sizeof(MAP));
@@ -580,7 +580,7 @@ URL url_buf;
 		for ( m = R_NEXT(MAP*,&r->c.map_parents) ;
 				m != (MAP*)&r->c.map_parents;
 				m = R_NEXT(MAP*,&m->h) )
-			if ( url_cmp(&m->src_url,&url_buf) == 0 )
+			if ( url_cmp_str(&m->src_url,&url_buf) == 0 )
 				goto next;
 
 
@@ -1033,7 +1033,7 @@ MAP * m;
 	for ( m = R_NEXT(MAP*,&c->c.map_children) ;
 			m != (MAP*)&c->c.map_children;
 			m = R_NEXT(MAP*,&m->h) ) {
-		if ( url_cmp(&m->src_url,&u)  )
+		if ( url_cmp_str(&m->src_url,&u)  )
 			continue;
 		if ( m->map_file )
 			ret = m->map_file;
