@@ -132,10 +132,24 @@ L_CHAR * url;
 		url = compose_url(map_url,src);
 		get_url2(&r->map.src,url);
 		setup_c_unit(&r->map.cu_src,-1,url,0,0);
+		if ( r->map.cu_src.system == 0 ) {
+			set_c_unit(&r->map.cu_src,
+				url,
+				l_string(std_cm,"base"),
+				l_string(std_cm,"m"));
+			r->h.flags |= RF_UNCACHE;
+		}
 		d_f_ree(url);
 		url = compose_url(map_url,dest);
 		get_url2(&r->map.dest,url);
 		setup_c_unit(&r->map.cu_dest,-1,url,0,0);
+		if ( r->map.cu_dest.system == 0 ) {
+			set_c_unit(&r->map.cu_dest,
+				url,
+				l_string(std_cm,"base"),
+				l_string(std_cm,"m"));
+			r->h.flags |= RF_UNCACHE;
+		}
 		d_f_ree(url);
 
 		d_f_ree(map_url);
