@@ -270,7 +270,7 @@ OVERLAY * search_overlay(URL * u)
 {
 OVERLAY * ov;
 	for ( ov = overlay_list; ov ; ov = ov->h.next )
-		if ( url_cmp(&ov->h.url,u) == 0 )
+		if ( url_cmp_str(&ov->h.url,u) == 0 )
 			return ov;
 	return ov;
 }
