@@ -20,7 +20,7 @@
 #include	"memory_debug.h"
 #include	"version.h"
 
-extern VERSION gb_proto_version,gb_code_version,gb_ap_version;
+extern VERSION gb_proto_version,gb_code_version,ap_version;
 
 void
 init_gb()
@@ -31,7 +31,7 @@ char * buf;
 	set_version(&gb_code_version);
 
 	buf = d_alloc(strlen(gb_code_version.name)
-		+ strlen(gb_code_version.version) + 20,254);
+		+ strlen(gb_code_version.version) + 20);
 
 	strcpy(buf,gb_code_version.name);
 	strcpy(&buf[strlen(buf)],"/");
@@ -47,15 +47,14 @@ init_gbs()
 char * buf;
 
 	init_gb();
-	set_version(&gb_ap_version);
+	set_version(&ap_version);
 
-	buf = d_alloc(strlen(gb_ap_version.name)
-		+ strlen(gb_ap_version.version) + 20,
-		246);
+	buf = d_alloc(strlen(ap_version.name)
+		+ strlen(ap_version.version) + 20);
 
-	strcpy(buf,gb_ap_version.name);
+	strcpy(buf,ap_version.name);
 	strcpy(&buf[strlen(buf)],"/");
-	strcpy(&buf[strlen(buf)],gb_ap_version.version);
+	strcpy(&buf[strlen(buf)],ap_version.version);
 	set_setagent_msg(buf);
 
 	d_f_ree(buf);
