@@ -31,6 +31,10 @@
 #include	"xl.h"
 #include	"win_flame.h"
 
+#define INVALID_TRANS_TIMEOUT		5
+#define INVALID_TRANS_CR_ERR_COUNT	5
+#define QUEUE_LENGTH			10
+
 typedef struct tree_cache_t {
 	Q_HEADER		h;
 	struct tree_cache_t *	next;
@@ -104,7 +108,7 @@ void gc_tree_cache_get();
 	tc_queue2.gc_func = gc_tree_cache_t;
 	tc_queue2.gc_get = gc_tree_cache_get;
 	tc_queue2.key_func = tc_task2;
-	tc_queue2.key_limit = 10;
+	tc_queue2.key_limit = QUEUE_LENGTH;
 	tc_queue2.pri = PRI_FETCH;
 	setup_queue(&tc_queue2);
 }
@@ -434,6 +438,10 @@ I_RECT ir;
 REAL1 dpm;
 TREE_CACHE * tc;
 unsigned int t;
+int nr_count,cr_err_count,cr_err_count_flag;
+unsigned int nr_time;
+WFID_INCLUDE_RESOURCE * wir;
+int cr_err_q;
 
 	que = (SYS_QUEUE *)GET_TKEY(d);
 	key = touch_qkey(que);
@@ -444,12 +452,40 @@ unsigned int t;
 	xli->a_type = XLA_SELF;
 	setup_i(xli);
 
+	nr_count = 0;
+	nr_time = 0;
+	cr_err_count = 0;
+	cr_err_count_flag = 0;
 	for ( ; ; ) {
 		gc_push(0,0,"tc_task2");
 		n1 = delete_queue(que,sq_key_cond,key,0);
 		if ( n1 == 0 )
 			break;
+		if ( cr_err_count_flag && cr_err_q > 0 ) {
+			cr_err_q --;
+			goto n1_free;
+		}
 		r = n1->tc->r;
+		wir = wf_search_wfid_include_resource(r);
+		if ( wir == 0 ) {
+			if ( nr_time == 0 )
+				nr_time = get_xltime();
+	
+			if ( get_xltime() - nr_time > INVALID_TRANS_TIMEOUT ) {
+				if ( nr_count == 0 ) {
+					np_divide_p_agent(&r->h.entry);
+					aboat_session(n1->data);
+					nr_count = 1;
+				}
+ss_printf("** ** * RESET STREAM %i - %i\n",nr_count,wir);
+				goto n1_free;
+			}
+		}
+		else {
+			nr_count = 0;
+			nr_time = 0;
+		}
+
 		switch ( get_type(n1->data) ) {
 		case XLT_ERROR:
 			fprintf(stderr,"r64 get error ");
@@ -479,23 +515,27 @@ unsigned int t;
 			goto n1_free;
 		}
 		data = n1->data;
-		err = list_error(data);
-		if ( get_type(err) == XLT_ERROR ) {
-			fprintf(stderr,"r64 get error (intermediate)");
-			print_sexp(s_stderr,err,0);
 
-			set_inc_status_error(r,n1->data);
-
-			fprintf(stderr,"\n");
-			goto n1_free;
-		}
 		n3 = n1;
 		t = get_xltime();
 		for ( n2 = n1 ; n2 ; n2 = n2->next ) {
 			tn = n2->tn;
 			r = n2->tc->r;
- 			(*n2->tc->get_pixels)(n2->tc,tn,
-				car(data),n2->tmp);
+			if ( get_type(data) == XLT_ERROR )
+				break;
+			err = list_error(car(data));
+			if ( get_type(err) == XLT_ERROR ) {
+				data = cdr(data);
+				n1->tn->flags |= TNF_ERROR;
+				continue;
+			}
+			if ( (*n2->tc->get_pixels)(n2->tc,tn,
+					car(data),n2->tmp) < 0 )
+				cr_err_count ++;
+			else {
+				cr_err_count = 0;
+				cr_err_count_flag = 0;
+			}
 			data = cdr(data);
 			if ( get_xltime() - t >= 2 )
 				n3 = tc_dirty_insert(n3,n2);
@@ -503,6 +543,14 @@ unsigned int t;
 		tc_dirty_insert(n3,0);
 		free_tc_t(n1,0);
 
+		if ( cr_err_count > INVALID_TRANS_CR_ERR_COUNT &&
+			cr_err_count_flag == 0 ) {
+			np_divide_p_agent(&r->h.entry);
+			aboat_session(n1->data);
+			cr_err_count_flag = 1;
+			cr_err_q = QUEUE_LENGTH;
+		}
+
 		gc_pop(0,0);
 		continue;
 	n1_free:
@@ -533,6 +581,7 @@ int w,h;
 int level;
 RESOURCE * r;
 extern int spiral_count;
+WFID_INCLUDE_RESOURCE * wir;
 
 	que = (SYS_QUEUE *)GET_TKEY(d);
 	key = touch_qkey(que);
@@ -549,18 +598,21 @@ extern int spiral_count;
 
 		cnt = 0;
 		n2 = 0;
-		for ( ; cnt < 20 ; ) {
+		for ( ; cnt < 2 ; ) {
 			n1 = delete_queue(que,sq_key_cond,key,0);
 			if ( n1 == 0 )
 				break;
 			lock_task(tc_lock);
 			unlock_task(tc_lock,"tc_task");
 			if ( n1->tc->r->pr64.loop_no - n1->loop_no
-					> spiral_count + 2 ) {
+					> spiral_count + 2 ||
+				(wir = wf_search_wfid_include_resource(n1->tc->r))
+					== 0 ) {
 				n1->next = 0;
 				free_tc_t(n1,TNF_ERROR);
 				continue;
 			}
+			free_wfid_include_resource(wir);
 			cnt ++;
 			n1->next = n2;
 			n2 = n1;
