@@ -2614,8 +2614,6 @@ WFID_INCLUDE_RESOURCE * ir;
 	r = w->r;
 
 	wf_lock(gf);
-set_t_msg(40);
-
 
 
 	for ( wf = gf->flame ; wf ; wf = wf->next ) {
@@ -2922,6 +2920,8 @@ GB_RECT rct;
 RESOURCE * map;
 WFID_INCLUDE_RESOURCE * wir,* p;
 	wir = wf_search_wfid_include_resource(r);
+if ( r->h.target.port == 9000 )
+ss_printf("********DIRTY 1 %x\n",wir);
 	for ( p = wir ; p ; p = p->next ) {
 		if ( p->id == 0 )
 			return;
@@ -2940,6 +2940,12 @@ WFID_INCLUDE_RESOURCE * wir,* p;
 		rct.tl.y -= ofs_h;
 		rct.br.x += ofs_w;
 		rct.br.y += ofs_h;
+if ( r->h.target.port == 9000 )
+ss_printf("********DIRTY %f %f - %f %f\n",
+rct.tl.x,
+rct.tl.y,
+rct.br.x,
+rct.br.y);
 		win_flame_dirty(p->gf,p->id,&rct,flags,0);
 
 		free_mh(mh);
