@@ -496,6 +496,14 @@ XL_SEXP * gt;
 L_CHAR * filename;
 STREAM * st;
 int len;
+L_CHAR * _f;
+	_f = get_url_filepath(u);
+	if ( path_check(_f) == 0 ) {
+		log_printf(LOG_DEBUG,"save_lr CHECK ERROR %ls\n",_f);
+		d_f_ree(_f);
+		return;
+	}
+	d_f_ree(_f);
 
 	gc_push(0,0,"save_lr");
 	gt = n_get_symbol("?xl");
