@@ -60,6 +60,7 @@ XL_SEXP *
 get_user_ip_for_set(XLISP_ENV * env,XL_SEXP * s)
 {
 XL_SEXP * ip, * a;
+
 	ip = get_user_ip(env);
 	switch ( get_type(ip) ) {
 	case XLT_ERROR:
@@ -246,6 +247,7 @@ XL_SEXP * where, * port;
 L_CHAR * _file;
 int p1;
 char buf[100];
+XL_INTERPRETER * xli;
 
 	_file = ll_copy_str(filename);
 	for ( p1 = l_strlen(_file)-1 ; p1 >= 0 ; p1 -- )
@@ -311,6 +313,16 @@ char buf[100];
 		goto url_error;
 	}
 	d_f_ree(db_res);
+	xli = get_my_xli();
+	if ( hostcmp(n_string(std_cm,u_map.server),getHA_v4(0),
+			0,getHA_v4(xli->connect_ip)) ) {
+		sprintf(buf,"map(%s %x)",n_string(std_cm,u_map.server),
+			xli->connect_ip);
+		where = n_get_string(buf);
+		goto url_permission;
+	}
+
+/*
 	a = get_user_ip_for_set(env,s);
 	if ( get_type(a) == XLT_ERROR ) {
 		ret = a;
@@ -323,6 +335,7 @@ char buf[100];
 		where = n_get_string(buf);
 		goto url_permission;
 	}
+*/
 	return 0;
 url_error:
 	ret = get_error(
@@ -698,6 +711,10 @@ ss_printf("MF %i %i %ls %ls %ls\n",mf,mf2,_filename,src->string.data,dest->strin
 		else if ( mf && mf2 )
 			send_cindex(_filename);
 	}
+	if ( get_type(ret) == XLT_ERROR ) {
+		log_print_sexp(LOG_ERROR,"Set operation error",
+			ret,0);
+	}
 	return ret;
 type_missmatch:
 	return get_error(
