@@ -37,9 +37,9 @@ MEM_LIST * get_mem_debug_list(MEM_LIST * m);
 
 
 void init_d_alloc();
-#define d_alloc(s,t)	xx_d_alloc((s),__FILE__,__LINE__)
+#define d_alloc(s)	xx_d_alloc((s),__FILE__,__LINE__)
 void *	d_re_alloc(void * ptr,int size);
-#define d_calloc(s,el,t)	xx_d_calloc((s),(el),__FILE__,__LINE__)
+#define d_calloc(s,el)	xx_d_calloc((s),(el),__FILE__,__LINE__)
 #define d_f_ree(x)	xx_d_f_ree((x),__FILE__,__LINE__)
 
 
