@@ -21,6 +21,29 @@
 
 #include	"machine/include.h"
 
+#define UTC_00_00_00_01_01_2001	978307200
+
+#define TFMT_UNIX	1
+#define TFMT_W3C_DTF	2
+
+typedef struct _sys_param {
+	unsigned int		cpu;
+	unsigned int		max_fd;
+} _SYS_PARAM;
+
+typedef struct _u_stat {
+	unsigned int		us_atime;
+	unsigned int		us_mtime;
+	unsigned int		us_ctime;
+} U_STAT;
+
+
+
+extern _SYS_PARAM	sys_param;
+
+int u_stat(char * path,U_STAT * buf);
+
+
 #ifndef U_FILE_LIB
 int u_open(char *,int,...);
 int u_open64(char *,int,...);
