@@ -168,7 +168,7 @@ int old_size;
 	LOCK;
 	if ( ptr == 0 ) {
 		UNLOCK;
-		return d_alloc(size,0); 
+		return d_alloc(size); 
 	}
 	mh = ptr;
 	mh = mh - 1;
