@@ -24,6 +24,7 @@
 #include <stdlib.h>
 #include "ppm_types.h"
 #include "ppmlib_types.h"
+#include "u_file.h"
 
 void
 read_pixel(PPM_INFO * p,unsigned int w,unsigned int h,unsigned char * c)
@@ -39,9 +40,9 @@ retry:
 	}
 	ofs = LINE_HEAD(p,h);
 	if ( ofs != p->pi_lastacc )
-		lseek(p->pi_fd,ofs,SEEK_SET);
+		u_lseek(p->pi_fd,ofs,SEEK_SET);
 	data = new_line(p,h);
-	read(p->pi_fd,data,p->pi_width*3);
+	u_read(p->pi_fd,data,p->pi_width*3);
 	p->pi_lastacc = ofs + p->pi_width*3;
 	goto retry;
 }
