@@ -21,23 +21,24 @@
 #include	<string.h>
 #include	"ppm_error.h"
 #include	"ppm_types.h"
+#include	"u_file.h"
 
 int
 write_ppm(PPM_INFO * p,unsigned char * data)
 {
 char buffer[100];
 int i,len;
-	if ( lseek(p->pi_fd,SEEK_SET,0) < 0 )
+	if ( u_lseek(p->pi_fd,SEEK_SET,0) < 0 )
 		return E_UNIX;
 	sprintf(buffer,"P6\n%i %i\n%i\n",
 		p->pi_width,
 		p->pi_height,
 		p->pi_max);
 	len = strlen(buffer);
-	if ( write(p->pi_fd,buffer,len) < len )
+	if ( u_write(p->pi_fd,buffer,len) < len )
 		return E_UNIX;
 	for ( i = p->pi_width*p->pi_height ; i ; i -- ) {
-		if ( write(p->pi_fd,data,3) < 3 )
+		if ( u_write(p->pi_fd,data,3) < 3 )
 			return E_UNIX;
 		data += 3;
 	}
