@@ -61,9 +61,9 @@ int er;
 	else	ce->h_len = f->level_h[level] - ce->h_ofs;
 	ofs2 = u_lseek64(f->fd,0,SEEK_END);
 	ofs1 = CH_OFS2_FILE(f,ce);
+
 /*
-if ( ofs1 > 0x7fffffff )
-printf("== over %x %x\n",ofs1,ofs2);
+printf("== over %i %i - %x %x\n",ce->w_ofs,ce->h_ofs,ofs1,ofs2);
 */
 	if ( ofs1 >= ofs2 ) {
 	broken:
