@@ -42,11 +42,15 @@ init_Get(XLISP_ENV * env)
 void
 lf_close_function(int type,LOAD_FILE_T * lft)
 {
+	if ( lft->path == 0 )
+		return;
 	switch ( type ) {
 	case CF_CLOSE:
 		call_unlock(lft->id);
 		d_f_ree(lft->path);
 		d_f_ree(lft);
+		lft->path = 0;
+		lft->id = cl_invalid();
 		break;
 	case CF_GC:
 		gc_gb_sexp(lft->s);
@@ -58,10 +62,10 @@ LOAD_FILE_T *
 new_lft(XL_SEXP * s,CALL_LOCK_DESCRIPTER id,L_CHAR * path)
 {
 LOAD_FILE_T * lft;
-	lft = d_alloc(sizeof(*lft),671);
+	lft = d_alloc(sizeof(*lft));
 	lft->s = s;
 	lft->id = id;
-	lft->path = ll_copy_str(path,1474);
+	lft->path = ll_copy_str(path);
 	return lft;
 }
 
@@ -133,8 +137,9 @@ int tim;
 				n_get_string("unsupport Get mode"));
 			i = 2;
 		}
-		if ( get_type(ret) == XLT_ERROR && lft )
+		if ( get_type(ret) == XLT_ERROR && lft ) {
 			lf_close_function(CF_CLOSE,lft);
+		}
 
 		if ( get_type(ret) != XLT_ERROR )
 			i = 2;
