@@ -75,6 +75,9 @@ DELAY_LOAD_T ** dp, * d;
 		if ( d->close_func )
 			(*d->close_func)(CF_CLOSE,d->work);
 		_s_close(d->st);
+		d->close_func = 0;
+		d->work = 0;
+		d->st = 0;
 		free_automaton(d->term_a);
 		if ( d->backbuffer )
 			d_f_ree(d->backbuffer);
@@ -319,7 +322,7 @@ STATE_CHECKER sc;
 					d_alloc(
 						sizeof(L_CHAR)*
 						((ptr-sc.endptr)
-						+ bb_size),123);
+						+ bb_size));
 				memcpy(df->backbuffer,
 					&data[sc.endptr],
 					sizeof(L_CHAR)*
