@@ -123,7 +123,7 @@ int st;
 PATH_ELEMENT * pl;
 	len = 0;
 	st = 1;
-	ppp->path = d_alloc(1,500);
+	ppp->path = d_alloc(1);
 	for ( ; ; ) {
 		for ( p = path , cnt = 0 ;
 				*p &&
@@ -137,7 +137,7 @@ PATH_ELEMENT * pl;
 			pl->type = PE_DIR;
 		}
 		else {
-			buf = d_alloc((cnt+1)*sizeof(L_CHAR),500);
+			buf = d_alloc((cnt+1)*sizeof(L_CHAR));
 			memcpy(buf,path,cnt*sizeof(L_CHAR));
 			buf[cnt] = 0;
 			ppp->path = d_re_alloc(ppp->path,
@@ -204,7 +204,7 @@ char * ret;
 int len,i,p;
 	for ( len = 0 , i = 0 ; i < pp->path_len ; i ++ )
 		len += strlen(pp->path[i].name) + 1;
-	ret = d_alloc(len+1,506);
+	ret = d_alloc(len+1);
 	for ( p = 0 , i = 0 ; i < pp->path_len ; i ++ ) {
 		strcpy(&ret[p],pp->path[i].name);
 		p += strlen(pp->path[i].name);
@@ -223,9 +223,9 @@ PATH_PATTERN * ret;
 PATH_ELEMENT * pe;
 int i;
 	if ( pp ) {
-		ret = d_alloc(sizeof(*ret),608);
+		ret = d_alloc(sizeof(*ret));
 		ret->path_len = pp->path_len + 1;
-		ret->path = d_alloc(sizeof(PATH_ELEMENT)*ret->path_len,609);
+		ret->path = d_alloc(sizeof(PATH_ELEMENT)*ret->path_len);
 		memcpy(ret->path,pp->path,sizeof(PATH_ELEMENT)*pp->path_len);
 		for ( i = 0 ; i < pp->path_len ; i ++ )
 {
@@ -239,9 +239,9 @@ int i;
 		ret->type = 0;
 	}
 	else {
-		ret = d_alloc(sizeof(*ret),610);
+		ret = d_alloc(sizeof(*ret));
 		ret->path_len = 1;
-		ret->path = d_alloc(sizeof(PATH_ELEMENT)*ret->path_len,611);
+		ret->path = d_alloc(sizeof(PATH_ELEMENT)*ret->path_len);
 		pe = &ret->path[0];
 		pe->type = type;
 		pe->name = copy_str(name);
@@ -279,8 +279,7 @@ PATH_PATTERN * pp,* pp1;
 		if ( d->d_name[0] == '.' )
 			continue;
 		buffer2 = d_alloc(strlen(buffer)+
-				strlen(d->d_name)+10,
-				503);
+				strlen(d->d_name)+10);
 		sprintf(buffer2,"%s/%s",buffer,d->d_name);
 		if ( stat(buffer2, &sbuf) < 0 ) {
 			fprintf(stderr,"\"%s\"",buffer2);
@@ -343,7 +342,7 @@ int * cnt;
 int len,i,j,c,len1;
 	len = strlen(n2);
 	len1 = strlen(n1);
-	cnt = d_alloc(len*sizeof(int),507);
+	cnt = d_alloc(len*sizeof(int));
 	for ( i = 0; i < len ; i ++ )
 		if ( n2[i] == '*' )
 			cnt[i] = 1;
@@ -481,11 +480,11 @@ copy_pp(PATH_PATTERN * pp)
 {
 PATH_PATTERN * ret;
 int i;
-	ret = d_alloc(sizeof(*ret),615);
+	ret = d_alloc(sizeof(*ret));
 	ret->next = 0;
 	ret->type = 0;
 	ret->path_len = pp->path_len;
-	ret->path = d_alloc(sizeof(PATH_ELEMENT)*ret->path_len,616);
+	ret->path = d_alloc(sizeof(PATH_ELEMENT)*ret->path_len);
 	memcpy(ret->path,pp->path,sizeof(PATH_ELEMENT)*ret->path_len);
 	for ( i = 0 ; i < ret->path_len ; i ++ )
 		ret->path[i].name = copy_str(ret->path[i].name);
@@ -596,7 +595,7 @@ char * buf;
 int er;
 
 
-	pp = d_alloc(sizeof(*pp),617);
+	pp = d_alloc(sizeof(*pp));
 	parse_path(pp,dir);
 	pp->next = 0;
 	len = pp->path_len;
@@ -841,7 +840,7 @@ int exec_type;
 #define ET_1BY1		1
 #define ET_ALLFOR1	2
 
-	pp = d_alloc(1,501);
+	pp = d_alloc(1);
 	len = 0;
 	s = cdr(s);
 	for ( ; get_type(s) ; s = cdr(s) ) {
