@@ -33,11 +33,12 @@ init_Sequence(XLISP_ENV * env)
 
 
 XL_SEXP *
-xl_Sequence(XLISP_ENV * env,XL_SEXP * s)
+xl_Sequence(XLISP_ENV * env,XL_SEXP * s,XLISP_ENV * a,XL_SYM_FIELD * sf)
 {
 XL_SEXP * s_env;
 XL_SEXP * r, * ret;
 XLISP_ENV * ee;
+L_CHAR * di;
 	s_env = eval(env,get_el(s,1));
 	switch ( get_type(s_env) ) {
 	case XLT_ERROR:
