@@ -1091,3 +1091,59 @@ int ret;
 		return CDT_NONDELAY;
 	}
 }
+
+
+
+int
+get_delay_info(STREAM ** st,XL_DELAY ** buf,XL_SEXP * s)
+{
+int t;
+XL_FILE * f,* f2;
+XL_DELAY * d;
+XL_SEXP * err, * data;
+int plt,plc;
+int ret;
+
+	if ( st )
+		*st = 0;
+	lock_parse();
+	if ( s == 0 ) {
+		unlock_parse("get_delay_info");
+		return CDT_NONDELAY;
+	}
+	if ( st )
+		*st = s->h.file->st;
+	if ( s->h.type != XLT_DELAY ) {
+		unlock_parse("get_delay_info");
+		return CDT_NONDELAY;
+	}
+	if ( s->h.file->flags & XLF_PARSE ) {
+		unlock_parse("get_delay_info");
+		return CDT_NONDELAY;
+	}
+	if ( s->h.type == XLT_DELAY ) {
+		if ( s->delay.dtype == GBDT_FUNC ) {
+		delay_retry:
+			f = s->h.file;
+			f->flags |= XLF_PARSE;
+			*buf = s->delay.d.func;
+			gc_set_nl(buf,s->delay.d.func->gc_func);
+			wakeup_task((int)f);
+			f->flags &= ~XLF_PARSE;
+			unlock_parse("get_delay_info");
+			return CDT_READY;
+		}
+		if ( st )
+			*st = s->delay.d.file.f->st;
+		unlock_parse("get_delay_info");
+		return CDT_STREAM;
+	}
+	else {
+		unlock_parse("get_delaya_info");
+		return CDT_NONDELAY;
+	}
+}
+
+
+
+
