@@ -16,11 +16,13 @@
 **********************************************************************/
 
 
+#include	<fcntl.h>
 #include	"xlerror.h"
 #include	"memory_debug.h"
 #include	"xl.h"
 #include	"long_char.h"
 #include	"utils.h"
+#include	"u_file.h"
 
 XL_GETFILE * getfile_hash[GETFILE_HASH_SIZE];
 L_CHAR * agent_name;
@@ -235,3 +237,50 @@ XL_FILE * file;
 	}
 	return 0;
 }
+
+L_CHAR *
+get_synth_path(L_CHAR * b,L_CHAR * filepath)
+{
+L_CHAR * path;
+int len,len_f;
+	path = ll_copy_str(b);
+	len = l_strlen(path);
+	len_f = l_strlen(filepath);
+	path = d_re_alloc(path,(len+len_f+1)*sizeof(L_CHAR));
+	memcpy(&path[len],filepath,(len_f+1)*sizeof(L_CHAR));
+	return path;
+}
+
+int
+path_check(L_CHAR * filepath)
+{
+L_CHAR * p;
+char * p1,* p2;
+int f;
+int ret;
+	ret = 0;
+	p = get_synth_path(docs_path,filepath);
+	p2 = change_delim_str(p1 = n_string(std_cm,p));
+	f = u_open(p2,O_RDONLY);
+	if ( p2 != p1 )
+		d_f_ree(p2);
+	d_f_ree(p);
+	if ( f >= 0 ) {
+		u_close(f);
+		ret |= 1;
+	}
+	p = get_synth_path(sys_path,filepath);
+	p2 = change_delim_str(p1 = n_string(std_cm,p));
+	f = u_open(p2,O_RDONLY);
+	if ( p2 != p1 )
+		d_f_ree(p2);
+	d_f_ree(p);
+	if ( f >= 0 ) {
+		u_close(f);
+		ret |= 2;
+	}
+	return ret;
+}
+
+
+
