@@ -1155,6 +1155,8 @@ void
 close_self_interpreter()
 {
 XL_INTERPRETER * xli;
+	gc_check_empty("close_self_interpreter");
+
 	lock_task(xli_lock);
 	xli = _get_my_xli();
 	_close_xl_interpreter(xli);
@@ -1650,7 +1652,7 @@ set_cpu_msg(0);
 end2:
 	gc_pop(0,0); /* section 1 level 2 */
 	gc_pop(0,0); /* section 1 level 1 */
-	gc_check_empty();
+	gc_check_empty("thread_1");
 
 	if ( agent_close_xli )
 		(*agent_close_xli)(xli);
@@ -1911,7 +1913,7 @@ set_t_msg(12);
 set_cpu_msg(10);
 set_t_msg(13);
 
-	gc_check_empty();
+	gc_check_empty("thread_2");
 
 set_cpu_msg(11);
 set_t_msg(14);
@@ -1992,6 +1994,10 @@ XL_SEXP * r, * ret;
 XL_SEXP * cmd;
 int line;
 
+void * stt, * stt_2;
+
+stt_2 = get_gc_check_point();
+
 	gc_push(0,0,"relay1"); /* section 0 level 1 */
 
 	for ( ; ; ) {
@@ -2060,7 +2066,13 @@ ss_printf("(%i)>>",get_xltime());
 print_sexp(s_stdout,r,PF_RAW_DISABLE);
 ss_printf("\n");
 */
+stt = get_gc_check_point();
+
+
 		ret = eval(xli->env,r);
+
+compare_gc_check_point("relay_eval",stt);
+
 /*
 ss_printf("(%i)>>RETURN\n",get_xltime());
 print_sexp(s_stdout,ret,PF_RAW_DISABLE);
@@ -2091,6 +2103,9 @@ ss_printf("\n");
 	}
 
 	gc_pop(0,0); /* section 0 level 1 */
+
+compare_gc_check_point("relay_loop",stt_2);
+
 }
 
 void
@@ -2100,9 +2115,32 @@ XL_SEXP * s, * r, * ret, * cmd;
 XL_INTERPRETER * xli;
 DELAY_QUE_T * n;
 
+void * stt;
+void * stt2;
+GC_STACK * sttt;
+
+stt2 = get_gc_check_point();
+if ( stt2 ) {
+sttt = stt2;
+fprintf(stderr,"STACK = %x\n",sttt);
+if ( sttt->msg )
+fprintf(stderr,"MSG = %s\n",sttt->msg);
+er_panic("_relay_thread");
+}
+
 set_cpu_thr_type(12);
 set_cpu_msg(0);
 
+stt = get_gc_check_point();
+if ( stt ) {
+sttt = stt;
+fprintf(stderr,"STACK = %x\n",sttt);
+if ( sttt->msg )
+fprintf(stderr,"MSG = %s\n",sttt->msg);
+er_panic("_relay_thread");
+}
+
+
 	xli = (XL_INTERPRETER*)GET_TKEY(k);
 	xli->relay_thread = _new_xli_thread(xli);
 	relay_loop(xli,XFF_BLOCK);
@@ -2177,10 +2215,13 @@ set_cpu_msg(19);
 
 set_cpu_msg(20);
 
+
 	_free_xli_thread();
 	unlock_task(xli_lock,"relay_thread");
 
-	gc_check_empty();
+compare_gc_check_point("relay_check",stt);
+
+	gc_check_empty("relay",stt);
 
 }
 
