@@ -439,19 +439,13 @@ XL_RESULT * resp;
 XL_SEXP * ret;
 void gc_gb_sexp();
 
-set_t_msg(2000);
 	lock_task(xli_lock);
-set_t_msg(2001);
 	resp = (XL_RESULT*)s->delay.d.func;
 	gc_push(0,0,"remote_delay_func");
-set_t_msg(2002);
 	ret = _wait_result_inp(resp);
-set_t_msg(2003);
 	gc_pop(ret,gc_gb_sexp);
 	over_write_sexp(s,ret);
-set_t_msg(2004);
 	unlock_task(xli_lock,"remote_delay_func");
-set_t_msg(2005);
 	return s;
 }
 
@@ -603,8 +597,8 @@ int len;
 				0));
 	}
 	else if ( cmd_str ) {
-		st_buf = d_alloc(50,172);
-		en_buf = d_alloc(50,173);
+		st_buf = d_alloc(50);
+		en_buf = d_alloc(50);
 		if ( cmd_str[0] == '<' ) {
 			sprintf(st_buf,"<LocalEval>%i ",xli->inp_line);
 			sprintf(en_buf,"</LocalEval>\n");
@@ -614,7 +608,7 @@ int len;
 			sprintf(en_buf,")\n");
 		}
 		len = strlen(st_buf) + strlen(en_buf) + l_strlen(cmd_str);
-		str = d_alloc((len+1)*sizeof(L_CHAR),174);
+		str = d_alloc((len+1)*sizeof(L_CHAR));
 		l_strcpy(str,l_string(std_cm,st_buf));
 		l_strcpy(&str[l_strlen(str)],cmd_str);
 		l_strcpy(&str[l_strlen(str)],l_string(std_cm,en_buf));
@@ -673,3 +667,35 @@ XL_SEXP * err;
 		delete_result_queue(xli,xli->result_head);
 
 }
+
+
+int
+aboat_remote_query(XL_SEXP * s)
+{
+STREAM * st;
+XL_RESULT * resp;
+XL_INTERPRETER * xli;
+int iid;
+	gc_push(0,0,"aboat_remote_query");
+	lock_task(xli_lock);
+	if ( get_delay_info(&st,(XL_DELAY**)&resp,s) == CDT_READY ) {
+		xli = resp->out_interpreter;
+		if ( xli )
+			iid = xli->id;
+		else	iid = 0;
+		unlock_task(xli_lock,"aboat_remote_query");
+		close_interpreter(iid);
+		gc_pop(0,0);
+		return 0;
+	}
+	unlock_task(xli_lock,"aboat_remote_query");
+	if ( st ) {
+		s_close(st);
+		gc_pop(0,0);
+		return 1;
+	}
+	gc_pop(0,0);
+	return -1;
+}
+
+
