@@ -1909,3 +1909,17 @@ XL_SEXP *ret;
 	return ret;
 }
 
+void
+np_divide_p_agent(URL * u)
+{
+	ss_printf("DIVIDE PROXY AGENT\n");	
+}
+
+
+int
+aboat_session(XL_SEXP * s)
+{
+	return aboat_remote_query(s);
+}
+
+
